@@ -4,12 +4,12 @@
 import logging
 
 logger = logging.getLogger("asammdf")
-formatter = logging.Formatter('%(name)s - %(levelname)s - %(message)s')
+formatter = logging.Formatter("%(name)s - %(levelname)s - %(message)s")
 console = logging.StreamHandler()
 console.setFormatter(formatter)
 console.setLevel(logging.DEBUG)
 logger.addHandler(console)
-logger.setLevel(logging.WARNING)
+logger.setLevel(logging.ERROR)
 
 
 from .blocks.mdf_v2 import MDF2
@@ -20,7 +20,22 @@ from .gui import plot
 from .signal import Signal
 from .version import __version__
 
+try:
+    from .blocks import cutils
+
+    __cextension__ = True
+except ImportError:
+    __cextension__ = False
+
 
 __all__ = [
-    "__version__", "MDF", "MDF2", "MDF3", "MDF4", "Signal", "SUPPORTED_VERSIONS", "plot"
+    "__cextension__",
+    "__version__",
+    "MDF",
+    "MDF2",
+    "MDF3",
+    "MDF4",
+    "Signal",
+    "SUPPORTED_VERSIONS",
+    "plot",
 ]
