@@ -51,6 +51,13 @@ SIGNED_INT = {DATA_TYPE_SIGNED_INTEL, DATA_TYPE_SIGNED_MOTOROLA}
 FLOATS = {DATA_TYPE_REAL_INTEL, DATA_TYPE_REAL_MOTOROLA}
 STANDARD_INT_SIZES = {8, 16, 32, 64}
 
+INT_TYPES = {
+    DATA_TYPE_UNSIGNED_INTEL,
+    DATA_TYPE_UNSIGNED_MOTOROLA,
+    DATA_TYPE_SIGNED_INTEL,
+    DATA_TYPE_SIGNED_MOTOROLA,
+}
+
 CHANNEL_TYPE_VALUE = 0
 CHANNEL_TYPE_VLSD = 1
 CHANNEL_TYPE_MASTER = 2
